This crate contains kube-rs compatible bindings for Kubernetes custom resources for the addons.cluster.x-k8s.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
addons.cluster.x-k8s.io/v1alpha3
ClusterResourceSetBindingClusterResourceSet
addons.cluster.x-k8s.io/v1alpha4
ClusterResourceSetBindingClusterResourceSet
addons.cluster.x-k8s.io/v1beta1
ClusterResourceSetBindingClusterResourceSet
addons.cluster.x-k8s.io/v1beta2
ClusterResourceSetBindingClusterResourceSet